@@ -1,12 +1,15 @@
+"""Helper Utility Functions"""
 import logging
 import os
-import yaml
 import re
+import yaml
 from es_client.defaults import config_schema
 from es_client.exceptions import ConfigurationError
 from es_client.helpers.schemacheck import SchemaCheck
 
-logger = logging.getLogger(__name__)
+LOGGER = logging.getLogger(__name__)
+
+ES_DEFAULT = {'elasticsearch':{'client':{'hosts':'http://127.0.0.1:9200'}}}
 
 def prune_nones(mydict):
     """
@@ -16,7 +19,7 @@ def prune_nones(mydict):
     :rtype: dict
     """
     # Test for `None` instead of existence or zero values will be caught
-    return dict([(k,v) for k, v in mydict.items() if v != None and v != 'None'])
+    return dict([(k,v) for k, v in mydict.items() if v is not None and v != 'None'])
 
 def ensure_list(data):
     """
@@ -37,33 +40,36 @@ def read_file(myfile):
     :rtype: str
     """
     try:
-        with open(myfile, 'r') as f:
+        with open(myfile, 'r', encoding='utf-8') as f:
             data = f.read()
         return data
-    except IOError as e:
-        msg = 'Unable to read file {0}. Exception: {1}'.format(myfile, e)
-        logger.error(msg)
-        raise ConfigurationError(msg)
+    except IOError as exc:
+        msg = f'Unable to read file {myfile}. Exception: {exc}'
+        LOGGER.error(msg)
+        raise ConfigurationError(msg) from exc
 
 def check_config(config):
     """
     Ensure that the top-level key ``elasticsearch`` and its sub-keys, ``other_settings`` and
-    ``client`` are in ``config`` before passing it to
+    ``client`` as contained in ``config`` before passing it (or empty defaults) to
     :class:`~es_client.helpers.schemacheck.SchemaCheck` for value validation.
     """
     if not isinstance(config, dict):
-        raise ConfigurationError('Must supply dictionary.  You supplied: "{0}" which is "{1}"'.format(config, type(config)))
-    if not 'elasticsearch' in config:
-        logger.warning('No "elasticsearch" setting in supplied configuration.  Using defaults.')
-        config['elasticsearch'] = {}
+        LOGGER.warning('Elasticsearch client configuration must be provided as a dictionary.')
+        LOGGER.warning('You supplied: "%s" which is "%s".', config, type(config))
+        LOGGER.warning('Using default values.')
+        es_settings = ES_DEFAULT
+    elif not 'elasticsearch' in config:
+        LOGGER.warning('No "elasticsearch" setting in supplied configuration.  Using defaults.')
+        es_settings = ES_DEFAULT
     else:
-        config = prune_nones(config)
+        es_settings = config
     for key in ['client', 'other_settings']:
-        if key not in config['elasticsearch']:
-            config['elasticsearch'][key] = {}
+        if key not in es_settings['elasticsearch']:
+            es_settings['elasticsearch'][key] = {}
         else:
-            config['elasticsearch'][key] = prune_nones(config['elasticsearch'][key])
-    return SchemaCheck(config['elasticsearch'], config_schema(),
+            es_settings['elasticsearch'][key] = prune_nones(es_settings['elasticsearch'][key])
+    return SchemaCheck(es_settings['elasticsearch'], config_schema(),
         'Elasticsearch Configuration', 'elasticsearch').result()
 
 def verify_ssl_paths(args):
@@ -111,22 +117,37 @@ def get_yaml(path):
 
     try:
         return yaml.load(read_file(path), Loader=yaml.FullLoader)
-    # except yaml.scanner.ScannerError as err:
-    #     print('Unable to read/parse YAML file: {0}'.format(path))
-    #     print(err)
-    except (yaml.scanner.ScannerError, yaml.parser.ParserError) as err:
-        raise ConfigurationError(
-            'Unable to parse YAML file. Error: {0}'.format(err))
+    except (yaml.scanner.ScannerError, yaml.parser.ParserError) as exc:
+        raise ConfigurationError(f'Unable to parse YAML file. Error: {exc}') from exc
 
 def verify_url_schema(url):
     """Ensure that a valid URL schema (HTTP[S]://URL:PORT) is used"""
-    parts = url.split(':')
+    parts = url.lower().split(':')
+    errmsg = f'URL Schema invalid for {url}'
     if len(parts) < 3:
         # We do not have a port
-        if parts[0].lower() == 'https':
+        if parts[0] == 'https':
             port = '443'
-        else:
+        elif parts[0] == 'http':
             port = '80'
-    else:
+        else:
+            raise ConfigurationError(errmsg)
+    elif len(parts) == 3:
+        if (parts[0] != 'http') and (parts[0] != 'https'):
+            raise ConfigurationError(errmsg)
         port = parts[2]
-    return parts[0] + ':' + parts[1] + ':' + port
\ No newline at end of file
+    else:
+        raise ConfigurationError(errmsg)
+    return parts[0] + ':' + parts[1] + ':' + port
+
+def get_version(client):
+    """Get the Elasticsearch version of the connected node"""
+    version = client.info()['version']['number']
+    # Split off any -dev, -beta, or -rc tags
+    version = version.split('-')[0]
+    # Only take SEMVER (drop any fields over 3)
+    if len(version.split('.')) > 3:
+        version = version.split('.')[:-1]
+    else:
+        version = version.split('.')
+    return tuple(map(int, version))
